@@ -13,7 +13,6 @@
 #include <netlink/netlink.h>
 #include <netlink/attr.h>
 #include <netlink/route/rtnl.h>
-#include <netlink/route/link/inet6.h>
 #include <netlink-private/route/link/api.h>
 
 #define I6_ADDR_GEN_MODE_UNKNOWN	UINT8_MAX
@@ -295,7 +294,6 @@ static char *inet6_devconf2str(int type, char *buf, size_t len)
 static const struct trans_tbl inet6_addr_gen_mode[] = {
 	__ADD(IN6_ADDR_GEN_MODE_EUI64, eui64),
 	__ADD(IN6_ADDR_GEN_MODE_NONE, none),
-	__ADD(IN6_ADDR_GEN_MODE_STABLE_PRIVACY, stable_privacy),
 };
 
 const char *rtnl_link_inet6_addrgenmode2str(uint8_t mode, char *buf, size_t len)
