@@ -62,11 +62,15 @@ static int ipip_alloc(struct rtnl_link *link)
 {
 	struct ipip_info *ipip;
 
-	ipip = calloc(1, sizeof(*ipip));
-	if (!ipip)
-		return -NLE_NOMEM;
+	if (link->l_info)
+		memset(link->l_info, 0, sizeof(*ipip));
+	else {
+		ipip = calloc(1, sizeof(*ipip));
+		if (!ipip)
+			return -NLE_NOMEM;
 
-	link->l_info = ipip;
+		link->l_info = ipip;
+	}
 
 	return 0;
 }
@@ -78,7 +82,7 @@ static int ipip_parse(struct rtnl_link *link, struct nlattr *data,
 	struct ipip_info *ipip;
 	int err;
 
-	NL_DBG(3, "Parsing IPIP link info");
+	NL_DBG(3, "Parsing IPIP link info\n");
 
 	err = nla_parse_nested(tb, IFLA_IPTUN_MAX, data, ipip_policy);
 	if (err < 0)
