@@ -277,9 +277,9 @@ uint32_t rtnl_route_nh_get_realms(struct rtnl_nexthop *nh)
  */
 
 static const struct trans_tbl nh_flags[] = {
-	__ADD(RTNH_F_DEAD, dead)
-	__ADD(RTNH_F_PERVASIVE, pervasive)
-	__ADD(RTNH_F_ONLINK, onlink)
+	__ADD(RTNH_F_DEAD, dead),
+	__ADD(RTNH_F_PERVASIVE, pervasive),
+	__ADD(RTNH_F_ONLINK, onlink),
 };
 
 char *rtnl_route_nh_flags2str(int flags, char *buf, size_t len)
