@@ -274,19 +274,19 @@ static int rule_compare(struct nl_object *_a, struct nl_object *_b,
 }
 
 static const struct trans_tbl rule_attrs[] = {
-	__ADD(RULE_ATTR_FAMILY, family)
-	__ADD(RULE_ATTR_TABLE, table)
-	__ADD(RULE_ATTR_ACTION, action)
-	__ADD(RULE_ATTR_IIFNAME, iifname)
-	__ADD(RULE_ATTR_OIFNAME, oifname)
-	__ADD(RULE_ATTR_PRIO, prio)
-	__ADD(RULE_ATTR_MARK, mark)
-	__ADD(RULE_ATTR_MASK, mask)
-	__ADD(RULE_ATTR_GOTO, goto)
-	__ADD(RULE_ATTR_SRC, src)
-	__ADD(RULE_ATTR_DST, dst)
-	__ADD(RULE_ATTR_DSFIELD, dsfield)
-	__ADD(RULE_ATTR_FLOW, flow)
+	__ADD(RULE_ATTR_FAMILY, family),
+	__ADD(RULE_ATTR_TABLE, table),
+	__ADD(RULE_ATTR_ACTION, action),
+	__ADD(RULE_ATTR_IIFNAME, iifname),
+	__ADD(RULE_ATTR_OIFNAME, oifname),
+	__ADD(RULE_ATTR_PRIO, prio),
+	__ADD(RULE_ATTR_MARK, mark),
+	__ADD(RULE_ATTR_MASK, mask),
+	__ADD(RULE_ATTR_GOTO, goto),
+	__ADD(RULE_ATTR_SRC, src),
+	__ADD(RULE_ATTR_DST, dst),
+	__ADD(RULE_ATTR_DSFIELD, dsfield),
+	__ADD(RULE_ATTR_FLOW, flow),
 };
 
 static char *rule_attrs2str(int attrs, char *buf, size_t len)
