@@ -903,39 +903,33 @@ void rtnl_tc_dump_details(struct nl_object *obj, struct nl_dump_params *p)
 void rtnl_tc_dump_stats(struct nl_object *obj, struct nl_dump_params *p)
 {
 	struct rtnl_tc *tc = TC_CAST(obj);
-	char *unit, fmt[64];
+	char *unit;
 	float res;
 
 	rtnl_tc_dump_details(OBJ_CAST(tc), p);
 
-	strcpy(fmt, "        %7.2f %s %10u %10u %10u %10u %10u\n");
-
-	nl_dump_line(p, 
-		"    Stats:    bytes    packets      drops overlimits" \
-		"       qlen    backlog\n");
+	nl_dump_line(p,
+	             "  stats: %-14s %-10s   %-10s %-10s %-10s %-10s\n",
+	             "bytes", "packets", "drops", "overlimits", "qlen", "backlog");
 
 	res = nl_cancel_down_bytes(tc->tc_stats[RTNL_TC_BYTES], &unit);
-	if (*unit == 'B')
-		fmt[11] = '9';
 
-	nl_dump_line(p, fmt, res, unit,
-		tc->tc_stats[RTNL_TC_PACKETS],
-		tc->tc_stats[RTNL_TC_DROPS],
-		tc->tc_stats[RTNL_TC_OVERLIMITS],
-		tc->tc_stats[RTNL_TC_QLEN],
-		tc->tc_stats[RTNL_TC_BACKLOG]);
+	nl_dump_line(p,
+	             "       %10.2f %3s   %10u   %-10u %-10u %-10u %-10u\n",
+	             res, unit,
+	             tc->tc_stats[RTNL_TC_PACKETS],
+	             tc->tc_stats[RTNL_TC_DROPS],
+	             tc->tc_stats[RTNL_TC_OVERLIMITS],
+	             tc->tc_stats[RTNL_TC_QLEN],
+	             tc->tc_stats[RTNL_TC_BACKLOG]);
 
 	res = nl_cancel_down_bytes(tc->tc_stats[RTNL_TC_RATE_BPS], &unit);
 
-	strcpy(fmt, "        %7.2f %s/s%9u pps");
-
-	if (*unit == 'B')
-		fmt[11] = '9';
-
-	nl_dump_line(p, fmt, res, unit, tc->tc_stats[RTNL_TC_RATE_PPS]);
-
-	tc_dump(tc, NL_DUMP_LINE, p);
-	nl_dump(p, "\n");
+	nl_dump_line(p,
+	             "       %10.2f %3s/s %10u/s\n",
+	             res,
+	             unit,
+	             tc->tc_stats[RTNL_TC_RATE_PPS]);
 }
 
 int rtnl_tc_compare(struct nl_object *aobj, struct nl_object *bobj,
@@ -1053,9 +1047,6 @@ void *rtnl_tc_data(struct rtnl_tc *tc)
 		size_t size;
 
 		if (!tc->tc_ops) {
-			if (!tc->tc_kind)
-				BUG();
-
 			if (!rtnl_tc_get_ops(tc))
 				return NULL;
 		}
