@@ -123,7 +123,6 @@
 #include <netlink/netlink.h>
 #include <netlink/cache.h>
 #include <netlink/object.h>
-#include <netlink/xfrm/ae.h>
 #include <linux/xfrm.h>
 
 /** @cond SKIP */
@@ -182,13 +181,11 @@ static int xfrm_ae_clone(struct nl_object *_dst, struct nl_object *_src)
 	return 0;
 }
 
-static uint64_t xfrm_ae_compare(struct nl_object *_a, struct nl_object *_b,
-				uint64_t attrs, int flags)
+static int xfrm_ae_compare(struct nl_object *_a, struct nl_object *_b, uint32_t attrs, int flags)
 {
 	struct xfrmnl_ae* a  =   (struct xfrmnl_ae *) _a;
 	struct xfrmnl_ae* b  =   (struct xfrmnl_ae *) _b;
-	uint64_t diff = 0;
-	int found = 0;
+	int diff = 0, found = 0;
 
 #define XFRM_AE_DIFF(ATTR, EXPR) ATTR_DIFF(attrs, XFRM_AE_ATTR_##ATTR, a, b, EXPR)
 	diff |= XFRM_AE_DIFF(DADDR,	nl_addr_cmp(a->sa_id.daddr, b->sa_id.daddr));
@@ -649,8 +646,8 @@ int xfrmnl_ae_get_kernel(struct nl_sock* sock, struct nl_addr* daddr, unsigned i
 	*result = (struct xfrmnl_ae *) obj;
 
 	/* If an object has been returned, we also need to wait for the ACK */
-	if (err == 0 && obj)
-		nl_wait_for_ack(sock);
+	 if (err == 0 && obj)
+		 nl_wait_for_ack(sock);
 
 	return 0;
 }
