@@ -52,9 +52,8 @@ int main(int argc, char *argv[])
 {
 	struct nl_sock *nf_sock;
 	struct nl_sock *rt_sock;
-        struct nl_cache *link_cache;
 	struct nfnl_log *log;
-	enum nfnl_log_copy_mode copy_mode;
+	int copy_mode;
 	uint32_t copy_range;
 	int err;
 	int family;
@@ -116,7 +115,7 @@ int main(int argc, char *argv[])
 
 	rt_sock = nl_cli_alloc_socket();
 	nl_cli_connect(rt_sock, NETLINK_ROUTE);
-	link_cache = nl_cli_link_alloc_cache(rt_sock);
+	nl_cli_link_alloc_cache(rt_sock);
 
 	while (1) {
 		fd_set rfds;
